==> haskell-safe-exceptions-0.1.7.1-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 safe-exceptions
version:              0.1.7.1
visibility:           public
id:                   safe-exceptions-0.1.7.1-DVtaT48Pz3UDvXAKjRjrBX
key:                  safe-exceptions-0.1.7.1-DVtaT48Pz3UDvXAKjRjrBX
license:              MIT
copyright:            2016 FP Complete
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/safe-exceptions#readme
synopsis:             Safe, consistent, and easy exception handling
description:          Please see README.md
category:             Control
abi:                  2c631b2bf7d0c82ec15201c56fe10f0d
exposed:              True
exposed-modules:      Control.Exception.Safe
import-dirs:          /usr/lib/ghc-8.10.4/site-local/safe-exceptions-0.1.7.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/safe-exceptions-0.1.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/safe-exceptions-0.1.7.1
hs-libraries:         HSsafe-exceptions-0.1.7.1-DVtaT48Pz3UDvXAKjRjrBX
depends:
    base-4.14.1.0 deepseq-1.4.4.0 exceptions-0.10.4
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safe-exceptions-0.1.7.1-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 safe-exceptions
version:              0.1.7.1
visibility:           public
id:                   safe-exceptions-0.1.7.1-FyR4QVF5CuiHECzxFccexa
key:                  safe-exceptions-0.1.7.1-FyR4QVF5CuiHECzxFccexa
license:              MIT
copyright:            2016 FP Complete
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/safe-exceptions#readme
synopsis:             Safe, consistent, and easy exception handling
description:          Please see README.md
category:             Control
abi:                  bdffdfbb43479d83c947a8b8b5aff60d
exposed:              True
exposed-modules:      Control.Exception.Safe
import-dirs:          /usr/lib/ghc-8.10.4/site-local/safe-exceptions-0.1.7.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/safe-exceptions-0.1.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/safe-exceptions-0.1.7.1
hs-libraries:         HSsafe-exceptions-0.1.7.1-FyR4QVF5CuiHECzxFccexa
depends:
    base-4.14.1.0 deepseq-1.4.4.0 exceptions-0.10.4
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
